@@ -17,11 +17,11 @@ LocalTest - Test functions for L<DBIx::NinjaORM>.
 
 =head1 VERSION
 
-Version 2.4.1
+Version 2.4.2
 
 =cut
 
-our $VERSION = '2.4.1';
+our $VERSION = '2.4.2';
 
 
 =head1 SYNOPSIS
@@ -203,9 +203,10 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-dbix-ninjaorm at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-NinjaORM>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/DBIx-NinjaORM/issues/new>.
+I will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
 
 
 =head1 SUPPORT
@@ -219,9 +220,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-NinjaORM>
+L<https://github.com/guillaumeaubert/DBIx-NinjaORM/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -231,9 +232,9 @@ L<http://annocpan.org/dist/DBIx-NinjaORM>
 
 L<http://cpanratings.perl.org/d/DBIx-NinjaORM>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/DBIx-NinjaORM/>
+L<https://metacpan.org/release/DBIx-NinjaORM>
 
 =back
 
